/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.programmation-facile.com/
  Portions created by the Initial Developer are Copyright (C) 2013
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */



/**
 * Classe Player qui gère le héros du jeu, le joueur.
 * 
 */
Player = function(game)
{
	this.oGame = game;
	this.spritePlayer = null;
	this.cursors = null;
	
};


/**
 * Définition des méthodes de la classe Player
 * 
 * @type {[type]}
 */
Player.prototype =
{

	/**
	 * Préchargement des éléments de la classe Player
	 * 
	 * @return {[type]} [description]
	 */
	preload: function () 
	{
		this.oGame.load.spritesheet('heros', 'assets/dude.png', 32, 48);// sprite / animations / ensemble d'images
	},


	/**
	 * Création de la scène du jeu,
	 * mise en place des graphismes...
	 * 
	 * @return {[type]} [description]
	 */
	create: function () 
	{
		this.spritePlayer = this.oGame.add.sprite(32, this.oGame.world.height - 150, 'heros');// gestion du joueur et ses paramètres
		this.oGame.physics.arcade.enable(this.spritePlayer);// active les lois physique sur le joueur
		
		// propriétés physiques du joueur. Ajoute un effet de rebond sur le joueur (gravité de la lune)
	    this.spritePlayer.body.bounce.y = 0.2;
	    this.spritePlayer.body.gravity.y = 300;
	    this.spritePlayer.body.collideWorldBounds = true;
	 
	    //  Ajoute les 2 animations, marcher à gauche et à droite
	    this.spritePlayer.animations.add('left', [0, 1, 2, 3], 10, true);
	    this.spritePlayer.animations.add('right', [5, 6, 7, 8], 10, true);

	    this.cursors = this.oGame.input.keyboard.createCursorKeys();// controle du héros avec les touches directionnelles
	},


	/**
	 * Le joueur a attrapé une étoile
	 * 
	 * @param  {[type]} player [description]
	 * @param  {[type]} star   [description]
	 * @return {[type]}        [description]
	 */
	collectStar: function(player, star) 
	{
	    star.kill();// supprime l'étoile de l'écran de jeu

	    // mets à jour le score du jeu
	    oTxtInfos.score += 13;
	    oTxtInfos.scoreText.text = 'Vos Points : ' + oTxtInfos.score;
	},


	/**
	 * Appelée en continu pendant le jeu
	 * 
	 * @return {[type]} [description]
	 */
	update: function()
	{
		this.oGame.physics.arcade.collide(this.spritePlayer, oLevel.platforms);// collission entre le joueur et les plateformes
	    this.oGame.physics.arcade.overlap(this.spritePlayer, oLevel.oGroupStars, this.collectStar, null, this);// vérifie si le joueur attrape une étoile, si oui appelle la fonction collectStar

	    // remise à zéro du mouvement du joueur
	    this.spritePlayer.body.velocity.x = 0;
	 
	    // les actions en fonction de la touche de direction pressée
	    if (this.cursors.left.isDown)
	    {
	        //  Mouvement vers la gauche
	        this.spritePlayer.body.velocity.x = -150;
	        this.spritePlayer.animations.play('left');// lance l'animation gauche
	    }
	    else if (this.cursors.right.isDown)
	    {
	        //  Mouvement vers la droite
	        this.spritePlayer.body.velocity.x = 150;
	        this.spritePlayer.animations.play('right');// lance l'animation droite
	    }
	    else
	    {
	        //  Le héros reste debout
	        this.spritePlayer.animations.stop();
	        this.spritePlayer.frame = 4;
	    }
	    
	    //  Permet au joueur de sauter lorsqu'il touche le sol
	    if (this.cursors.up.isDown && this.spritePlayer.body.touching.down)
	        this.spritePlayer.body.velocity.y = -350;

	}

};


